@@ -200,7 +200,7 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
       title = objs[0]->imp()->type()->translatedName();
   }
   else
-    title = i18n( "%1 Objects", objs.size() );
+    title = i18np( "%1 Object", "%1 Objects", objs.size() );
   addTitle( title );
 
   if ( !empty )
@@ -381,7 +381,7 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
       p.fill( QColor( colors[i].color ) );
       popup.addInternalAction( menu, QIcon( p ), i18n( colors[i].name ), nextfree++ );
     }
-    popup.addInternalAction( menu, KIcon( "colorize", l ), i18n( "&Custom Color" ), nextfree++ );
+    popup.addInternalAction( menu, KIcon( "color", l ), i18n( "&Custom Color" ), nextfree++ );
   }
   else if ( menu == NormalModePopupObjects::SetSizeMenu && !popup.onlyLabels() )
   {
