@@ -29,34 +29,38 @@
 #include "skymap.h"
 #include "kstarsdata.h"
 #include "ksnumbers.h"
-#include "ksplanet.h"
-#include "kssun.h"
-#include "ksmoon.h"
-#include "kspluto.h"
+#include "skyobjects/ksplanet.h"
+#include "skyobjects/kssun.h"
+#include "skyobjects/ksmoon.h"
+#include "skyobjects/kspluto.h"
 #include "jupitermoonscomponent.h"
+#include "saturnmoonscomponent.h"
 
-
-SolarSystemComposite::SolarSystemComposite(SkyComponent *parent, KStarsData *data )
+// FIXME: is KStarsData needed here
+SolarSystemComposite::SolarSystemComposite(SkyComponent *parent, KStarsData * )
         : SkyComposite(parent)
 {
 
-    m_Earth = new KSPlanet( data, I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
+    m_Earth = new KSPlanet( I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
 
-    m_Sun = new KSSun(data);
+    m_Sun = new KSSun();
     addComponent( new SolarSystemSingleComponent( this, m_Sun, Options::showSun, 8 ) );
-    m_Moon = new KSMoon(data);
+    m_Moon = new KSMoon();
     addComponent( new SolarSystemSingleComponent( this, m_Moon, Options::showMoon, 8 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::MERCURY ), Options::showMercury, 4 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::VENUS ), Options::showVenus, 4 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::MARS ), Options::showMars, 4 ) );
-    SolarSystemSingleComponent *jup = new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::JUPITER ), Options::showJupiter, 4 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MERCURY ), Options::showMercury, 4 ) );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::VENUS ), Options::showVenus, 4 ) );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MARS ), Options::showMars, 4 ) );
+    SolarSystemSingleComponent *jup = new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::JUPITER ), Options::showJupiter, 4 );
     addComponent( jup );
     m_JupiterMoons = new JupiterMoonsComponent( this, jup, &Options::showJupiter);
     addComponent( m_JupiterMoons );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::SATURN ), Options::showSaturn, 4 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::URANUS ), Options::showUranus, 4 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( data, KSPlanetBase::NEPTUNE ), Options::showNeptune, 4 ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPluto(data), Options::showPluto, 4 ) );
+    SolarSystemSingleComponent *sat = new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::SATURN ), Options::showSaturn, 4 );
+    addComponent( sat );
+    m_SaturnMoons = new SaturnMoonsComponent( this, sat, &Options::showSaturn);
+    addComponent( m_SaturnMoons );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::URANUS ), Options::showUranus, 4 ) );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::NEPTUNE ), Options::showNeptune, 4 ) );
+    addComponent( new SolarSystemSingleComponent( this, new KSPluto(), Options::showPluto, 4 ) );
 
     m_AsteroidsComponent = new AsteroidsComponent( this, Options::showAsteroids );
     addComponent( m_AsteroidsComponent );
@@ -93,6 +97,7 @@ void SolarSystemComposite::update( KStarsData *data, KSNumbers *num )
     m_Sun->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
     m_Moon->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
     m_JupiterMoons->update( data, num );
+    m_SaturnMoons->update( data, num );
 
     foreach ( SkyComponent *comp, components() ) {
         comp->update( data, num );
@@ -115,8 +120,9 @@ void SolarSystemComposite::updateMoons( KStarsData *data, KSNumbers *num )
 
     m_Sun->findPosition( num );
     m_Moon->findPosition( num, data->geo()->lat(), data->lst() );
-    m_Moon->findPhase( m_Sun );
+    m_Moon->findPhase();
     m_JupiterMoons->updateMoons( data, num );
+    m_SaturnMoons->updateMoons( data, num );
 }
 
 void SolarSystemComposite::draw( QPainter& psky )
