@@ -27,10 +27,10 @@
 #include "dms.h"
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "skypoint.h"
+#include "skyobjects/skypoint.h"
 #include "ksutils.h"
 #include "ksnumbers.h"
-#include "finddialog.h"
+#include "dialogs/finddialog.h"
 #include "widgets/dmsbox.h"
 
 modCalcEclCoords::modCalcEclCoords(QWidget *parentSplit)
@@ -72,13 +72,14 @@ void modCalcEclCoords::slotNow() {
 }
 
 void modCalcEclCoords::slotObject() {
-    FindDialog fd( (KStars*)topLevelWidget()->parent() );
-    if ( fd.exec() == QDialog::Accepted ) {
-        SkyObject *o = fd.selectedObject();
+    QPointer<FindDialog> fd = new FindDialog( (KStars*)topLevelWidget()->parent() );
+    if ( fd->exec() == QDialog::Accepted ) {
+        SkyObject *o = fd->selectedObject();
         RA->showInHours( o->ra() );
         Dec->showInDegrees( o->dec() );
         slotCompute();
     }
+    delete fd;
 }
 
 void modCalcEclCoords::slotDateTimeChanged(const QDateTime &edt) {
@@ -193,7 +194,7 @@ void modCalcEclCoords::slotEclLongCheckedBatch(){
 
 void modCalcEclCoords::slotRunBatch() {
 
-    QString inputFileName = InputFileBoxBatch->url().path();
+    QString inputFileName = InputFileBoxBatch->url().toLocalFile();
 
     // We open the input file and read its content
 
@@ -225,13 +226,13 @@ void modCalcEclCoords::processLines( QTextStream &istream ) {
     // we open the output file
 
     //	QTextStream istream(&fIn);
-    QString outputFileName = OutputFileBoxBatch->url().path();
+    QString outputFileName = OutputFileBoxBatch->url().toLocalFile();
     QFile fOut( outputFileName );
     fOut.open(QIODevice::WriteOnly); // TODO error checking
     QTextStream ostream(&fOut);
 
     QString line;
-    QString space = " ";
+    QChar space = ' ';
     int i = 0;
     SkyPoint sp;
     dms raB, decB, eclLatB, eclLongB;
