@@ -39,9 +39,9 @@
 #include "ksutils.h"
 #include "ksnumbers.h"
 #include "ksfilereader.h"
-#include "ksplanetbase.h"
-#include "ksplanet.h"
-#include "kspluto.h"
+#include "skyobjects/ksplanetbase.h"
+#include "skyobjects/ksplanet.h"
+#include "skyobjects/kspluto.h"
 #include "dms.h"
 #include "widgets/timestepbox.h"
 
@@ -66,6 +66,8 @@ PlanetViewer::PlanetViewer(QWidget *parent)
     pw->TimeStep->tsbox()->setValue( 1 ); //start with 1-day timestep
 
     pw->RunButton->setIcon( KIcon("arrow-right") );
+    pw->ZoomInButton->setIcon( KIcon("zoom-in") );
+    pw->ZoomOutButton->setIcon( KIcon("zoom-out") );
     pw->DateBox->setDate( ((KStars*)parent)->data()->lt().date() );
 
     resize( 500, 500 );
@@ -76,7 +78,7 @@ PlanetViewer::PlanetViewer(QWidget *parent)
     KStarsData *data = KStarsData::Instance();
     PlanetList.append( KSPlanetBase::createPlanet( KSPlanetBase::MERCURY ) );
     PlanetList.append( KSPlanetBase::createPlanet( KSPlanetBase::VENUS ) );
-    PlanetList.append( new KSPlanet( data, "Earth" ) );
+    PlanetList.append( new KSPlanet( "Earth" ) );
     PlanetList.append( KSPlanetBase::createPlanet( KSPlanetBase::MARS ) );
     PlanetList.append( KSPlanetBase::createPlanet( KSPlanetBase::JUPITER ) );
     PlanetList.append( KSPlanetBase::createPlanet( KSPlanetBase::SATURN ) );
@@ -108,6 +110,8 @@ PlanetViewer::PlanetViewer(QWidget *parent)
     connect( &tmr, SIGNAL( timeout() ), SLOT( tick() ) );
     connect( pw->TimeStep, SIGNAL( scaleChanged(float) ), SLOT( setTimeScale(float) ) );
     connect( pw->RunButton, SIGNAL( clicked() ), SLOT( slotRunClock() ) );
+    connect( pw->ZoomInButton, SIGNAL( clicked() ), SLOT( slotMapZoomIn() ) );
+    connect( pw->ZoomOutButton, SIGNAL( clicked() ), SLOT( slotMapZoomOut() ) );
     connect( pw->DateBox, SIGNAL( valueChanged( const QDate & ) ), SLOT( slotChangeDate( const QDate & ) ) );
     connect( pw->TodayButton, SIGNAL( clicked() ), SLOT( slotToday() ) );
     connect( this, SIGNAL( closeClicked() ), SLOT( slotCloseWindow() ) );
@@ -260,4 +264,12 @@ void PlanetViewer::keyPressEvent( QKeyEvent *e ) {
     }
 }
 
+void PlanetViewer::slotMapZoomIn() {
+    pw->map->slotZoomIn();
+}
+
+void PlanetViewer::slotMapZoomOut() {
+    pw->map->slotZoomOut();
+}
+
 #include "planetviewer.moc"
