@@ -32,11 +32,11 @@
 #include "skymap.h"
 #include "ksnumbers.h"
 #include "simclock.h"
-#include "detaildialog.h"
-#include "locationdialog.h"
-#include "timedialog.h"
-#include "kssun.h"
-#include "ksmoon.h"
+#include "dialogs/detaildialog.h"
+#include "dialogs/locationdialog.h"
+#include "dialogs/timedialog.h"
+#include "skyobjects/kssun.h"
+#include "skyobjects/ksmoon.h"
 
 WUTDialogUI::WUTDialogUI( QWidget *p ) : QFrame( p ) {
     setupUi( this );
@@ -165,9 +165,9 @@ void WUTDialog::init() {
         sDuration = KGlobal::locale()->formatTime( tDur );
     }
 
-    WUT->SunSetLabel->setText( i18n( "Sunset: %1" , sSet) );
-    WUT->SunRiseLabel->setText( i18n( "Sunrise: %1" , sRise) );
-    WUT->NightDurationLabel->setText( i18n( "Night duration: %1 hours", sDuration ) );
+    WUT->SunSetLabel->setText( i18nc( "Sunset at time %1 on date %2", "Sunset: %1 on %2" , sSet, KGlobal::locale()->formatDate( Evening.date(), KLocale::LongDate) ) );
+    WUT->SunRiseLabel->setText( i18nc( "Sunrise at time %1 on date %2", "Sunrise: %1 on %2" , sRise, KGlobal::locale()->formatDate( Tomorrow.date(), KLocale::LongDate) ) );
+    WUT->NightDurationLabel->setText( i18n("Night duration: %1 hours", sDuration ) );
 
     // moon almanac information
     KSMoon *oMoon = (KSMoon*) kstars->data()->objectNamed( "Moon" );
@@ -190,16 +190,16 @@ void WUTDialog::init() {
         sSet = KGlobal::locale()->formatTime( moonSet.addSecs(30) );
     }
 
-    WUT->MoonRiseLabel->setText( i18n( "Moon rises at: %1", sRise ) );
-    WUT->MoonSetLabel->setText( i18n( "Moon sets at: %1", sSet ) );
-    oMoon->findPhase( oSun );
+    WUT->MoonRiseLabel->setText( i18n( "Moon rises at: %1 on %2", sRise, KGlobal::locale()->formatDate( Evening.date(), KLocale::LongDate) ) );
+    WUT->MoonSetLabel->setText( i18n( "Moon sets at: %1 on %2", sSet, KGlobal::locale()->formatDate( Tomorrow.date(), KLocale::LongDate) ) );
+    oMoon->findPhase();
     WUT->MoonIllumLabel->setText( oMoon->phaseName() + QString( " (%1%)" ).arg(
                                       int(100.0*oMoon->illum() ) ) );
 
     //Restore Sun's and Moon's coordinates, and recompute Moon's original Phase
     oMoon->updateCoords( oldNum, true, geo->lat(), kstars->LST() );
     oSun->updateCoords( oldNum, true, geo->lat(), kstars->LST() );
-    oMoon->findPhase( oSun );
+    oMoon->findPhase();
 
     if ( WUT->CategoryListWidget->currentItem() )
         slotLoadList( WUT->CategoryListWidget->currentItem()->text() );
@@ -424,15 +424,26 @@ void WUTDialog::slotDetails() {
         o = kstars->data()->objectNamed( WUT->ObjectListWidget->currentItem()->text() );
     }
     if (o != 0) {
-        DetailDialog detail(o, kstars->data()->LTime, geo, kstars);
-        detail.exec();
+        QPointer<DetailDialog> detail = new DetailDialog(o, kstars->data()->LTime, geo, kstars);
+        detail->exec();
+	delete detail;
     }
 }
 
 void WUTDialog::slotChangeDate() {
-    TimeDialog td( T0, kstars->geo(), this );
-    if ( td.exec() == QDialog::Accepted ) {
-        T0 = td.selectedDateTime();
+
+    // Set the time T0 to the evening of today. This will make life easier for the user, who most probably 
+    // wants to see what's up on the night of some date, rather than the night of the previous day
+    T0.setTime( QTime( 18, 0, 0 ) ); // 6 PM
+
+    QPointer<TimeDialog> td = new TimeDialog( T0, kstars->geo(), this );
+    if ( td->exec() == QDialog::Accepted ) {
+        T0 = td->selectedDateTime();
+
+        // If the time is set to 12 midnight, set it to 00:00:01, so that we don't have date interpretation problems
+        if ( T0.time() == QTime( 0, 0, 0 ) )
+            T0.setTime( QTime( 0, 0, 1 ) );
+
         //If the Time is earlier than 6:00 am, assume the user wants the night of the previous date
         if ( T0.time().hour() < 6 )
             T0 = T0.addDays( -1 );
@@ -455,12 +466,13 @@ void WUTDialog::slotChangeDate() {
         init();
         slotLoadList( WUT->CategoryListWidget->currentItem()->text() );
     }
+    delete td;
 }
 
 void WUTDialog::slotChangeLocation() {
-    LocationDialog ld( kstars );
-    if ( ld.exec() == QDialog::Accepted ) {
-        GeoLocation *newGeo = ld.selectedCity();
+    QPointer<LocationDialog> ld = new LocationDialog( kstars );
+    if ( ld->exec() == QDialog::Accepted ) {
+        GeoLocation *newGeo = ld->selectedCity();
         if ( newGeo ) {
             geo = newGeo;
             UT0 = geo->LTtoUT( T0 );
@@ -473,6 +485,7 @@ void WUTDialog::slotChangeLocation() {
             slotLoadList( WUT->CategoryListWidget->currentItem()->text() );
         }
     }
+    delete ld;
 }
 
 void WUTDialog::slotEveningMorning( int index ) {
