@@ -560,7 +560,7 @@ void Executer::executeForTo(TreeNode* node) {
 		firstIteration = true;
 	}
 
-        QString id = QString("__%1_%2").arg(node->token()->look()).arg((long)node);
+	QString id = QString("__%1_%2").arg(node->token()->look()).arg((long)node);
 
 	if(breaking) {
 		breaking = false;
@@ -572,7 +572,6 @@ void Executer::executeForTo(TreeNode* node) {
 		return;
 	}
 
-
 	if (currentVariableTable()->contains(id)) {
 		newScope = node; // re-execute the expressions
 		currentVariableTable()->remove(id);
@@ -585,12 +584,10 @@ void Executer::executeForTo(TreeNode* node) {
 	double endCondition   = node->child(2)->value()->number();
 	double step           = node->child(3)->value()->number();
 
-	if (
- 	(startCondition < endCondition && currentCount + step <= endCondition) ||
-	    (startCondition > endCondition && currentCount + step >= endCondition && step<0) //negative loop sanity check, is it implemented?
-		|| (startCondition==endCondition && firstIteration) // for expressions like for $n=1 to 1
-	   ) {
-	if (!firstIteration)
+	if ((startCondition < endCondition && currentCount + step <= endCondition) ||
+	    (startCondition > endCondition && currentCount + step >= endCondition && step<0) ||  //negative loop sanity check, is it implemented?
+	    (startCondition ==endCondition && firstIteration) ) { // for expressions like for $n=1 to 1
+		if (!firstIteration)
 			(*currentVariableTable())[node->child(0)->token()->look()].setNumber(currentCount + step);
 		newScope = node->child(4); // (re-)execute the scope
 	} else {
@@ -722,7 +719,7 @@ void Executer::executeLessOrEquals(TreeNode* node) {
 void Executer::executeAddition(TreeNode* node) {
 //	qDebug() << "Executer::executeAddition()";
 	if(node->childCount()!=2) {
-		addError(i18n("You need two numbers or string to do an addition"), *node->token(), 0);
+		addError(i18n("You need two numbers or strings to do an addition"), *node->token(), 0);
 		return;
 	}
 	if (node->child(0)->value()->type() == Value::Number && node->child(1)->value()->type() == Value::Number) {
@@ -749,16 +746,16 @@ void Executer::executeSubstracton(TreeNode* node) {
 void Executer::executeMultiplication(TreeNode* node) {
 //	qDebug() << "Executer::executeMultiplication()";
 	if(node->childCount()!=2) {
-		addError(i18n("You need two numbers to multiplicate"), *node->token(), 0);
+		addError(i18n("You need two numbers to multiply"), *node->token(), 0);
 		return;
 	}
 	if (node->child(0)->value()->type() == Value::Number && node->child(1)->value()->type() == Value::Number) {
 		node->value()->setNumber(node->child(0)->value()->number() * node->child(1)->value()->number());
 	} else {
 		if (node->child(0)->value()->type() != Value::Number)
-			addError(i18n("You tried to multiplicate a non-number, '%1'", node->child(0)->token()->look()), *node->token(), 0);
+			addError(i18n("You tried to multiply a non-number, '%1'", node->child(0)->token()->look()), *node->token(), 0);
 		if (node->child(1)->value()->type() != Value::Number)
-			addError(i18n("You tried to multiplicate by a non-number, '%1'", node->child(1)->token()->look()), *node->token(), 0);
+			addError(i18n("You tried to multiply by a non-number, '%1'", node->child(1)->token()->look()), *node->token(), 0);
 	}
 }
 void Executer::executeDivision(TreeNode* node) {
@@ -811,7 +808,7 @@ void Executer::executeAssign(TreeNode* node) {
 void Executer::executeLearn(TreeNode* node) {
 //	qDebug() << "Executer::executeLearn()";
 	if(functionTable.contains(node->child(0)->token()->look())) {
-		addError(i18n("The function '%1' is already defined!", node->child(0)->token()->look()), *node->token(), 0);
+		addError(i18n("The function '%1' is already defined.", node->child(0)->token()->look()), *node->token(), 0);
 		return;
 	}
 	functionTable.insert(node->child(0)->token()->look(), node);
