@@ -167,8 +167,9 @@ class MainWindow : public KXmlGuiWindow
 		KAction *runAct;
 		KAction *pauseAct;
 		KAction *abortAct;
+		KAction *executeConsoleAct;
 		KAction *quitAct;
-		QAction *contextHelpAct;
+		KAction *contextHelpAct;
 		KAction *fullSpeedAct;
 		KAction *slowSpeedAct;
 		KAction *slowerSpeedAct;
