@@ -30,29 +30,30 @@ ControlView::ControlView( QWidget *parent )
 
     resize( 680, 640 );
 
-    m_control = new MarbleControlBox( this );
+    QVBoxLayout *vlayout = new QVBoxLayout( this );
+    vlayout->setMargin(0);
+
     m_splitter = new QSplitter (this);
+    vlayout->addWidget( m_splitter );
+
+    m_control = new MarbleControlBox( this );
+    m_splitter->addWidget( m_control );
+    m_splitter->setStretchFactor(m_splitter->indexOf(m_control), 0);
 
     m_marbleWidget = new MarbleWidget( this );
     m_marbleWidget->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding,
                                                 QSizePolicy::MinimumExpanding ) );
 
-    QVBoxLayout *vlayout = new QVBoxLayout( this );
-
-    m_splitter->addWidget( m_control );
     m_splitter->addWidget( m_marbleWidget );
-    m_splitter->setSizes( QList<int>() << 180 << width()-180 );
-    m_splitter->setStretchFactor(m_splitter->indexOf(m_control), 0);
     m_splitter->setStretchFactor(m_splitter->indexOf(m_marbleWidget), 1);
-
-    vlayout->addWidget( m_splitter );
-    vlayout->setMargin(0);
+    m_splitter->setSizes( QList<int>() << 180 << width()-180 );
 
     m_control->addMarbleWidget( m_marbleWidget );
 
     m_mapThemeManager = new MapThemeManager;
 
     m_control->setMapThemeModel( m_mapThemeManager->mapThemeModel() );
+    m_control->updateMapThemeView();
 }
 
 ControlView::~ControlView()
@@ -115,11 +116,6 @@ void ControlView::setCurrentLocationTabShown( bool show )
     m_control->setCurrentLocationTabShown( show );
 }
 
-void ControlView::setCurrentLocation2TabShown( bool show )
-{
-    m_control->setCurrentLocation2TabShown( show );
-}
-
 void ControlView::setFileViewTabShown( bool show )
 {
     m_control->setFileViewTabShown( show );
