@@ -22,6 +22,12 @@ class GeoDataColorStylePrivate
     {
     }
 
+    GeoDataColorStylePrivate( const GeoDataColorStylePrivate& other )
+      : m_color( other.m_color ),
+        m_colorMode( other.m_colorMode )
+    {
+    }
+
     ~GeoDataColorStylePrivate()
     {
     }
@@ -33,7 +39,13 @@ class GeoDataColorStylePrivate
 };
 
 GeoDataColorStyle::GeoDataColorStyle()
-      : d( new GeoDataColorStylePrivate() )
+      : d( new GeoDataColorStylePrivate )
+{
+}
+
+GeoDataColorStyle::GeoDataColorStyle( const GeoDataColorStyle& other )
+      : GeoDataObject( other ),
+        d( new GeoDataColorStylePrivate( *other.d ) )
 {
 }
 
@@ -42,6 +54,13 @@ GeoDataColorStyle::~GeoDataColorStyle()
     delete d;
 }
 
+GeoDataColorStyle& GeoDataColorStyle::operator=( const GeoDataColorStyle& other )
+{
+    GeoDataObject::operator=( other );
+    *d = *other.d;
+    return *this;
+}
+
 void GeoDataColorStyle::setColor( const QColor &value )
 {
     d->m_color = value;
