@@ -26,9 +26,16 @@ class GeoDataLabelStylePrivate
 {
   public:
     GeoDataLabelStylePrivate() 
-        : m_font( QFont("Sans Serif").family(), defaultSize, 50, false ),
+        : m_scale( 1.0 ),
           m_alignment( GeoDataLabelStyle::Corner ),
-          m_scale( 1.0 )
+          m_font( QFont("Sans Serif").family(), defaultSize, 50, false )
+    {
+    }
+
+    GeoDataLabelStylePrivate( const GeoDataLabelStylePrivate& other )
+        : m_scale( other.m_scale ),
+          m_alignment( other.m_alignment ),
+          m_font( other.m_font )
     {
     }
 
@@ -57,6 +64,11 @@ GeoDataLabelStyle::GeoDataLabelStyle()
     setColor( QColor( Qt::black ) );
 }
 
+GeoDataLabelStyle::GeoDataLabelStyle( const GeoDataLabelStyle& other )
+    : GeoDataColorStyle( other ), d (new GeoDataLabelStylePrivate( *other.d ) )
+{
+}
+
 GeoDataLabelStyle::GeoDataLabelStyle( const QFont &font, const QColor &color )
     : d (new GeoDataLabelStylePrivate( font ) )
 {
@@ -68,6 +80,13 @@ GeoDataLabelStyle::~GeoDataLabelStyle()
     delete d;
 }
 
+GeoDataLabelStyle& GeoDataLabelStyle::operator=( const GeoDataLabelStyle& other )
+{
+    GeoDataColorStyle::operator=( other );
+    *d = *other.d;
+    return *this;
+}
+
 void GeoDataLabelStyle::setAlignment( GeoDataLabelStyle::Alignment alignment )
 {
     d->m_alignment = alignment;
