@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlSourceDirTagHandler : public GeoTagHandler {
-public:
-    DgmlSourceDirTagHandler();
-    virtual ~DgmlSourceDirTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlSourceDirTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlSourceDirTagHandler_h
