@@ -25,10 +25,14 @@
 #include <geodata_export.h>
 #include "GeoDocument.h"
 
+namespace Marble
+{
+
 /**
  * @short Zoom properties of a GeoScene document.
  */
-class GEODATA_EXPORT GeoSceneZoom : public GeoNode {
+class GEODATA_EXPORT GeoSceneZoom : public GeoNode
+{
  public:
     GeoSceneZoom();
     ~GeoSceneZoom();
@@ -49,5 +53,6 @@ class GEODATA_EXPORT GeoSceneZoom : public GeoNode {
     // FIXME: d-pointerfy
 };
 
+}
 
 #endif // GEOSCENEZOOM_H
