@@ -13,7 +13,6 @@
 #include <QtCore/QDebug>
 
 #include "AbstractLayerData.h"
-#include "BoundingBox.h"
 
 using namespace Marble;
 
@@ -22,17 +21,6 @@ TrackContainer::TrackContainer() : AbstractLayerContainer()
 {
 }*/
 
-void TrackContainer::draw( ClipPainter *painter, 
-                           const QSize &canvasSize, ViewParams *viewParams,
-                           const BoundingBox &box )
-{
-    const_iterator it;
-
-    for( it = constBegin() ; it < constEnd() ; ++it ) {
-        (*it)->draw( painter, canvasSize, viewParams, box);
-    }
-}
-
 void TrackContainer::draw( ClipPainter *painter, 
                            const QSize &canvasSize,
                            ViewParams *viewParams )
