@@ -90,10 +90,14 @@ ParleyMainWindow::ParleyMainWindow(const QString& appName, const KUrl & filename
     QTimer::singleShot( 0, this, SLOT( startupTipOfDay() ) );
 }
 
+void ParleyMainWindow::addRecentFile(const KUrl &url, const QString &name)
+{
+    m_recentFilesAction->addUrl(url, name);
+    m_recentFilesAction->saveEntries(KGlobal::config()->group("Recent Files"));
+}
+
 void ParleyMainWindow::saveOptions()
 {
-    m_recentFilesAction->saveEntries(KGlobal::config()->group("Recent Files"));
-
 ///@todo save selection per document
 //     if (m_tableView) {
 //         // map to original entry numbers:
@@ -106,11 +110,16 @@ void ParleyMainWindow::saveOptions()
 
 void ParleyMainWindow::slotUpdateWindowCaption()
 {
-    QString title = m_document->document()->title();
-    if (title == i18n("Untitled")) {
-        title.clear();
+    QString title;
+    bool modified = false;
+    if (m_document->document()) {
+        title = m_document->document()->title();
+        modified = m_document->document()->isModified();
+        if (title == i18n("Untitled")) {
+            title.clear();
+        }
     }
-    setCaption(title, m_document->document()->isModified());
+    setCaption(title, modified);
 }
 
 void ParleyMainWindow::slotShowStatistics()
@@ -451,6 +460,10 @@ void ParleyMainWindow::switchComponent(Component component)
 
     m_currentComponent = component;
     setupToolbarMenuActions();
+
+    if (component == EditorComponent) {
+        m_editor->updateScriptMenu();
+    }
 }
 
 void ParleyMainWindow::showDocumentActions(bool open, bool edit)
